GroupEncryptResult class

Result of encrypting a group message.

Constructors

GroupEncryptResult({required Uint8List ciphertext, required Uint8List senderKeyRecord})
const

Properties

ciphertext Uint8List
The encrypted message.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderKeyRecord Uint8List
The updated sender key record.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override