PrivateKey class abstract

Constructors

PrivateKey()

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether the underlying Arc is disposed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

agree({required PublicKey publicKey}) Uint8List
Perform X25519 key agreement with a public key.
cloneKey() PrivateKey
Create a copy of this private key.
dispose() → void
Dispose the underlying Arc.
inherited
getPublicKey() PublicKey
Get the public key corresponding to this private key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize this private key to bytes.
sign({required List<int> message}) Uint8List
Sign a message with this private key.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

deserialize({required List<int> bytes}) PrivateKey
Deserialize a private key from bytes.
generate() PrivateKey
Generate a new random private key.