SignedPreKeyRecord class abstract
Constructors
-
SignedPreKeyRecord({required int id, required BigInt timestamp, required PublicKey publicKey, required PrivateKey privateKey, required List<
int> signature}) -
Create a new signed pre-key record.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
Whether the underlying
Arcis disposed.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Dispose the underlying
Arc.inherited -
id(
) → int - Get the signed pre-key ID.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
privateKey(
) → Uint8List - Get the private key.
-
publicKey(
) → Uint8List - Get the public key.
-
serialize(
) → Uint8List - Serialize this signed pre-key record to bytes.
-
signature(
) → Uint8List - Get the signature.
-
timestamp(
) → BigInt - Get the timestamp when this key was generated.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deserialize(
{required List< int> bytes}) → SignedPreKeyRecord - Deserialize a signed pre-key record from bytes.